@@ -1,25 +1,24 @@
 /*-GNU-GPL-BEGIN-*
-nepim - network pipemeter
-Copyright (C) 2005 Everton da Silva Marques
+nepim - network pipemeter - measuring network bandwidth between hosts
+Copyright (C) 2005  Everton da Silva Marques
 
-nepim is free software; you can redistribute it and/or modify
+This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+the Free Software Foundation; either version 2 of the License, or (at
+your option) any later version.
 
-nepim is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with nepim; see the file COPYING.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.
+along with this program; see the file COPYING; if not, write to the
+Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-
-/* $Id: slot.c,v 1.27 2005/09/30 11:55:40 evertonm Exp $ */
+/* $Id: slot.c,v 1.28 2005/11/04 09:56:15 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
